#!/bin/sh

export hunspell_VERSION=1.7.0
export hunspell_ARCHIVE=v${hunspell_VERSION}.tar.gz
export hunspell_DIRNAME=hunspell-${hunspell_VERSION}
export hunspell_URL=https://github.com/hunspell/hunspell/archive/${hunspell_ARCHIVE}

export poppler_VERSION=21.02.0
export poppler_ARCHIVE=poppler-${poppler_VERSION}.tar.xz
export poppler_DIRNAME=poppler-${poppler_VERSION}
export poppler_URL=https://poppler.freedesktop.org/${poppler_ARCHIVE}
